# SPDX-License-Identifier: Apache-2.0
# Copyright (c) 2022 Dell Inc, or its subsidiaries.

import grpc

from .proto.v1 import inventory_pb2, inventory_pb2_grpc


def get_inventory(address):
    try:
        with grpc.insecure_channel(address) as channel:
            stub = inventory_pb2_grpc.InventoryServiceStub(channel)
            res = stub.GetInventory(request=inventory_pb2.GetInventoryRequest())
            return res
    except grpc.RpcError as e:
        print(e)



import logging
import re

import redfish


class Systems:
    def __init__(self, host, user, password, **kwargs):
        """
        Create a new connection to DPU via Redfish.
        Due to timeout restrictions, every command will start its own session
        and tear it down once it completes.
        """
        self.logger = logging.getLogger("dpuredfish")
        self._host = host
        self._user = user
        self._password = password
        self._system_name = None
        self.logger.info("Connecting to %s", host)
        self._session = redfish.redfish_client(
            base_url=self._host,
            username=self._user,
            password=self._password,
            cafile=None,
            capath=None,
            max_retry=3,
            timeout=120,
            **kwargs
        )

    @property
    def system_name(self):
        self.logger.info("Getting System ID...")
        if self._system_name is not None:
            return self._system_name
        systems = self._session.get("/redfish/v1/Systems").obj.Members
        response = self._session.get(systems[0]["@odata.id"])
        self.logger.debug("Getting System ID ({})...".format(response.obj.Id))
        self._system_name = re.split(r"\d$", response.obj.Id)[0]
        return self._system_name

    def get_processors(self):
        self.logger.info("Getting Processors")
        # TODO: create decorator for login/logout
        self._session.login(auth=redfish.AuthMethod.SESSION)
        response = self._session.get(
            "/redfish/v1/Systems/{}/Processors?$expand=.($levels=1)".format(
                self.system_name
            )
        )
        self.logger.debug(response.text)
        self._session.logout()
        for item in response.obj.Members:
            yield item

    def get_storage(self):
        self.logger.info("Getting Storage ...")
        # TODO: create decorator for login/logout
        self._session.login(auth=redfish.AuthMethod.SESSION)
        response = self._session.get(
            "/redfish/v1/Systems/{}/Storage?$expand=~($levels=1)".format(
                self.system_name
            )
        )
        self.logger.debug(response.text)
        self._session.logout()
        return response.obj

    def get_memory(self):
        self.logger.info("Getting Memory")
        # TODO: create decorator for login/logout
        self._session.login(auth=redfish.AuthMethod.SESSION)
        response = self._session.get(
            "/redfish/v1/Systems/{}/Memory?$expand=.($levels=1)".format(
                self.system_name
            )
        )
        self.logger.debug(response.text)
        self._session.logout()
        for ch in response.obj.Members:
            yield ch

    def get_networks(self):
        self.logger.info("Getting EthernetInterfaces")
        # TODO: create decorator for login/logout
        self._session.login(auth=redfish.AuthMethod.SESSION)
        response = self._session.get(
            "/redfish/v1/Systems/{}/EthernetInterfaces?$expand=.($levels=1)".format(
                self.system_name
            )
        )
        self.logger.debug(response.text)
        self._session.logout()
        for item in response.obj.Members:
            yield item



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: backend_null.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
import opicommon_pb2 as opicommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x62\x61\x63kend_null.proto\x12\x12opi_api.storage.v1\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x0fopicommon.proto\"\xe1\x01\n\nNullVolume\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12#\n\nblock_size\x18\x02 \x01(\x03\x42\x04\xe2\x41\x01\x02R\tblockSize\x12\'\n\x0c\x62locks_count\x18\x03 \x01(\x03\x42\x04\xe2\x41\x01\x02R\x0b\x62locksCount\x12\x18\n\x04uuid\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01R\x04uuid:Q\xea\x41N\n\x1dopi_api.storage.v1/NullVolume\x12\x14nullVolumes/{volume}*\x0bnullVolumes2\nnullVolume\"\x8c\x01\n\x17\x43reateNullVolumeRequest\x12\x45\n\x0bnull_volume\x18\x01 \x01(\x0b\x32\x1e.opi_api.storage.v1.NullVolumeB\x04\xe2\x41\x01\x02R\nnullVolume\x12*\n\x0enull_volume_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0cnullVolumeId\"\x80\x01\n\x17\x44\x65leteNullVolumeRequest\x12:\n\x04name\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.storage.v1/NullVolumeR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xce\x01\n\x17UpdateNullVolumeRequest\x12\x45\n\x0bnull_volume\x18\x01 \x01(\x0b\x32\x1e.opi_api.storage.v1.NullVolumeB\x04\xe2\x41\x01\x02R\nnullVolume\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"`\n\x16ListNullVolumesRequest\x12!\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x84\x01\n\x17ListNullVolumesResponse\x12\x41\n\x0cnull_volumes\x18\x01 \x03(\x0b\x32\x1e.opi_api.storage.v1.NullVolumeR\x0bnullVolumes\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"R\n\x14GetNullVolumeRequest\x12:\n\x04name\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.storage.v1/NullVolumeR\x04name\"T\n\x16StatsNullVolumeRequest\x12:\n\x04name\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.storage.v1/NullVolumeR\x04name\"P\n\x17StatsNullVolumeResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats2\x99\x07\n\x11NullVolumeService\x12\xa2\x01\n\x10\x43reateNullVolume\x12+.opi_api.storage.v1.CreateNullVolumeRequest\x1a\x1e.opi_api.storage.v1.NullVolume\"A\xda\x41\x1anull_volume,null_volume_id\x82\xd3\xe4\x93\x02\x1e\"\x0f/v1/nullVolumes:\x0bnull_volume\x12\x80\x01\n\x10\x44\x65leteNullVolume\x12+.opi_api.storage.v1.DeleteNullVolumeRequest\x1a\x16.google.protobuf.Empty\"\'\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1a*\x18/v1/{name=nullVolumes/*}\x12\xb4\x01\n\x10UpdateNullVolume\x12+.opi_api.storage.v1.UpdateNullVolumeRequest\x1a\x1e.opi_api.storage.v1.NullVolume\"S\xda\x41\x17null_volume,update_mask\x82\xd3\xe4\x93\x02\x33\x32$/v1/{null_volume.name=nullVolumes/*}:\x0bnull_volume\x12\x83\x01\n\x0fListNullVolumes\x12*.opi_api.storage.v1.ListNullVolumesRequest\x1a+.opi_api.storage.v1.ListNullVolumesResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/nullVolumes\x12\x82\x01\n\rGetNullVolume\x12(.opi_api.storage.v1.GetNullVolumeRequest\x1a\x1e.opi_api.storage.v1.NullVolume\"\'\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/{name=nullVolumes/*}\x12\x99\x01\n\x0fStatsNullVolume\x12*.opi_api.storage.v1.StatsNullVolumeRequest\x1a+.opi_api.storage.v1.StatsNullVolumeResponse\"-\xda\x41\x04name\x82\xd3\xe4\x93\x02 \x12\x1e/v1/{name=nullVolumes/*}:statsB_\n\x12opi_api.storage.v1B\x10\x42\x61\x63kendNullProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'backend_null_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\020BackendNullProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_NULLVOLUME'].fields_by_name['name']._options = None
  _globals['_NULLVOLUME'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NULLVOLUME'].fields_by_name['block_size']._options = None
  _globals['_NULLVOLUME'].fields_by_name['block_size']._serialized_options = b'\342A\001\002'
  _globals['_NULLVOLUME'].fields_by_name['blocks_count']._options = None
  _globals['_NULLVOLUME'].fields_by_name['blocks_count']._serialized_options = b'\342A\001\002'
  _globals['_NULLVOLUME'].fields_by_name['uuid']._options = None
  _globals['_NULLVOLUME'].fields_by_name['uuid']._serialized_options = b'\342A\001\001'
  _globals['_NULLVOLUME']._options = None
  _globals['_NULLVOLUME']._serialized_options = b'\352AN\n\035opi_api.storage.v1/NullVolume\022\024nullVolumes/{volume}*\013nullVolumes2\nnullVolume'
  _globals['_CREATENULLVOLUMEREQUEST'].fields_by_name['null_volume']._options = None
  _globals['_CREATENULLVOLUMEREQUEST'].fields_by_name['null_volume']._serialized_options = b'\342A\001\002'
  _globals['_CREATENULLVOLUMEREQUEST'].fields_by_name['null_volume_id']._options = None
  _globals['_CREATENULLVOLUMEREQUEST'].fields_by_name['null_volume_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETENULLVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETENULLVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.storage.v1/NullVolume'
  _globals['_DELETENULLVOLUMEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETENULLVOLUMEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENULLVOLUMEREQUEST'].fields_by_name['null_volume']._options = None
  _globals['_UPDATENULLVOLUMEREQUEST'].fields_by_name['null_volume']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENULLVOLUMEREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATENULLVOLUMEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENULLVOLUMEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATENULLVOLUMEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTNULLVOLUMESREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNULLVOLUMESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNULLVOLUMESREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNULLVOLUMESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETNULLVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNULLVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.storage.v1/NullVolume'
  _globals['_STATSNULLVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSNULLVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.storage.v1/NullVolume'
  _globals['_NULLVOLUMESERVICE'].methods_by_name['CreateNullVolume']._options = None
  _globals['_NULLVOLUMESERVICE'].methods_by_name['CreateNullVolume']._serialized_options = b'\332A\032null_volume,null_volume_id\202\323\344\223\002\036\"\017/v1/nullVolumes:\013null_volume'
  _globals['_NULLVOLUMESERVICE'].methods_by_name['DeleteNullVolume']._options = None
  _globals['_NULLVOLUMESERVICE'].methods_by_name['DeleteNullVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\032*\030/v1/{name=nullVolumes/*}'
  _globals['_NULLVOLUMESERVICE'].methods_by_name['UpdateNullVolume']._options = None
  _globals['_NULLVOLUMESERVICE'].methods_by_name['UpdateNullVolume']._serialized_options = b'\332A\027null_volume,update_mask\202\323\344\223\00232$/v1/{null_volume.name=nullVolumes/*}:\013null_volume'
  _globals['_NULLVOLUMESERVICE'].methods_by_name['ListNullVolumes']._options = None
  _globals['_NULLVOLUMESERVICE'].methods_by_name['ListNullVolumes']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/nullVolumes'
  _globals['_NULLVOLUMESERVICE'].methods_by_name['GetNullVolume']._options = None
  _globals['_NULLVOLUMESERVICE'].methods_by_name['GetNullVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\032\022\030/v1/{name=nullVolumes/*}'
  _globals['_NULLVOLUMESERVICE'].methods_by_name['StatsNullVolume']._options = None
  _globals['_NULLVOLUMESERVICE'].methods_by_name['StatsNullVolume']._serialized_options = b'\332A\004name\202\323\344\223\002 \022\036/v1/{name=nullVolumes/*}:stats'
  _globals['_NULLVOLUME']._serialized_start=238
  _globals['_NULLVOLUME']._serialized_end=463
  _globals['_CREATENULLVOLUMEREQUEST']._serialized_start=466
  _globals['_CREATENULLVOLUMEREQUEST']._serialized_end=606
  _globals['_DELETENULLVOLUMEREQUEST']._serialized_start=609
  _globals['_DELETENULLVOLUMEREQUEST']._serialized_end=737
  _globals['_UPDATENULLVOLUMEREQUEST']._serialized_start=740
  _globals['_UPDATENULLVOLUMEREQUEST']._serialized_end=946
  _globals['_LISTNULLVOLUMESREQUEST']._serialized_start=948
  _globals['_LISTNULLVOLUMESREQUEST']._serialized_end=1044
  _globals['_LISTNULLVOLUMESRESPONSE']._serialized_start=1047
  _globals['_LISTNULLVOLUMESRESPONSE']._serialized_end=1179
  _globals['_GETNULLVOLUMEREQUEST']._serialized_start=1181
  _globals['_GETNULLVOLUMEREQUEST']._serialized_end=1263
  _globals['_STATSNULLVOLUMEREQUEST']._serialized_start=1265
  _globals['_STATSNULLVOLUMEREQUEST']._serialized_end=1349
  _globals['_STATSNULLVOLUMERESPONSE']._serialized_start=1351
  _globals['_STATSNULLVOLUMERESPONSE']._serialized_end=1431
  _globals['_NULLVOLUMESERVICE']._serialized_start=1434
  _globals['_NULLVOLUMESERVICE']._serialized_end=2355
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: inventory.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0finventory.proto\x12\x14opi_api.inventory.v1\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\"P\n\x08\x42IOSInfo\x12\x16\n\x06vendor\x18\x01 \x01(\tR\x06vendor\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version\x12\x12\n\x04\x64\x61te\x18\x03 \x01(\tR\x04\x64\x61te\"\xb5\x01\n\nSystemInfo\x12\x16\n\x06\x66\x61mily\x18\x01 \x01(\tR\x06\x66\x61mily\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x16\n\x06vendor\x18\x03 \x01(\tR\x06vendor\x12#\n\rserial_number\x18\x04 \x01(\tR\x0cserialNumber\x12\x12\n\x04uuid\x18\x05 \x01(\tR\x04uuid\x12\x10\n\x03sku\x18\x06 \x01(\tR\x03sku\x12\x18\n\x07version\x18\x07 \x01(\tR\x07version\"\xc0\x01\n\x0b\x43hassisInfo\x12\x1b\n\tasset_tag\x18\x01 \x01(\tR\x08\x61ssetTag\x12#\n\rserial_number\x18\x02 \x01(\tR\x0cserialNumber\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12)\n\x10type_description\x18\x04 \x01(\tR\x0ftypeDescription\x12\x16\n\x06vendor\x18\x05 \x01(\tR\x06vendor\x12\x18\n\x07version\x18\x06 \x01(\tR\x07version\"\x9d\x01\n\rBaseboardInfo\x12\x1b\n\tasset_tag\x18\x01 \x01(\tR\x08\x61ssetTag\x12#\n\rserial_number\x18\x02 \x01(\tR\x0cserialNumber\x12\x16\n\x06vendor\x18\x03 \x01(\tR\x06vendor\x12\x18\n\x07version\x18\x04 \x01(\tR\x07version\x12\x18\n\x07product\x18\x05 \x01(\tR\x07product\"O\n\x07\x43PUInfo\x12\x1f\n\x0btotal_cores\x18\x01 \x01(\x05R\ntotalCores\x12#\n\rtotal_threads\x18\x02 \x01(\x05R\x0ctotalThreads\"l\n\nMemoryInfo\x12\x30\n\x14total_physical_bytes\x18\x01 \x01(\x03R\x12totalPhysicalBytes\x12,\n\x12total_usable_bytes\x18\x02 \x01(\x03R\x10totalUsableBytes\"\xe0\x01\n\x0ePCIeDeviceInfo\x12\x16\n\x06\x64river\x18\x01 \x01(\tR\x06\x64river\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\x12\x16\n\x06vendor\x18\x03 \x01(\tR\x06vendor\x12\x18\n\x07product\x18\x04 \x01(\tR\x07product\x12\x1a\n\x08revision\x18\x05 \x01(\tR\x08revision\x12\x1c\n\tsubsystem\x18\x06 \x01(\tR\tsubsystem\x12\x14\n\x05\x63lass\x18\x07 \x01(\tR\x05\x63lass\x12\x1a\n\x08subclass\x18\x08 \x01(\tR\x08subclass\"R\n\x13GetInventoryRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1eopi_api.inventory.v1/InventoryR\x04name\"\xa8\x03\n\tInventory\x12\x32\n\x04\x62ios\x18\x01 \x01(\x0b\x32\x1e.opi_api.inventory.v1.BIOSInfoR\x04\x62ios\x12\x38\n\x06system\x18\x02 \x01(\x0b\x32 .opi_api.inventory.v1.SystemInfoR\x06system\x12\x41\n\tbaseboard\x18\x03 \x01(\x0b\x32#.opi_api.inventory.v1.BaseboardInfoR\tbaseboard\x12;\n\x07\x63hassis\x18\x04 \x01(\x0b\x32!.opi_api.inventory.v1.ChassisInfoR\x07\x63hassis\x12;\n\tprocessor\x18\x05 \x01(\x0b\x32\x1d.opi_api.inventory.v1.CPUInfoR\tprocessor\x12\x38\n\x06memory\x18\x06 \x01(\x0b\x32 .opi_api.inventory.v1.MemoryInfoR\x06memory\x12\x36\n\x03pci\x18\x07 \x03(\x0b\x32$.opi_api.inventory.v1.PCIeDeviceInfoR\x03pci2\xa2\x01\n\x10InventoryService\x12\x8d\x01\n\x0cGetInventory\x12).opi_api.inventory.v1.GetInventoryRequest\x1a\x1f.opi_api.inventory.v1.Inventory\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$\x12\"/v1/{name=inventory/*/inventory/*}B[\n\x14opi_api.inventory.v1B\x0eInventoryProtoP\x01Z1github.com/opiproject/opi-api/inventory/v1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'inventory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024opi_api.inventory.v1B\016InventoryProtoP\001Z1github.com/opiproject/opi-api/inventory/v1/gen/go'
  _globals['_GETINVENTORYREQUEST'].fields_by_name['name']._options = None
  _globals['_GETINVENTORYREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036opi_api.inventory.v1/Inventory'
  _globals['_INVENTORYSERVICE'].methods_by_name['GetInventory']._options = None
  _globals['_INVENTORYSERVICE'].methods_by_name['GetInventory']._serialized_options = b'\332A\004name\202\323\344\223\002$\022\"/v1/{name=inventory/*/inventory/*}'
  _globals['_BIOSINFO']._serialized_start=156
  _globals['_BIOSINFO']._serialized_end=236
  _globals['_SYSTEMINFO']._serialized_start=239
  _globals['_SYSTEMINFO']._serialized_end=420
  _globals['_CHASSISINFO']._serialized_start=423
  _globals['_CHASSISINFO']._serialized_end=615
  _globals['_BASEBOARDINFO']._serialized_start=618
  _globals['_BASEBOARDINFO']._serialized_end=775
  _globals['_CPUINFO']._serialized_start=777
  _globals['_CPUINFO']._serialized_end=856
  _globals['_MEMORYINFO']._serialized_start=858
  _globals['_MEMORYINFO']._serialized_end=966
  _globals['_PCIEDEVICEINFO']._serialized_start=969
  _globals['_PCIEDEVICEINFO']._serialized_end=1193
  _globals['_GETINVENTORYREQUEST']._serialized_start=1195
  _globals['_GETINVENTORYREQUEST']._serialized_end=1277
  _globals['_INVENTORY']._serialized_start=1280
  _globals['_INVENTORY']._serialized_end=1704
  _globals['_INVENTORYSERVICE']._serialized_start=1707
  _globals['_INVENTORYSERVICE']._serialized_end=1869
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: underlayroute.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13underlayroute.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\x8a\x02\n\rUnderlayRoute\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x45\n\x04spec\x18\x02 \x01(\x0b\x32\x31.opi_api.network.cloud.v1alpha1.UnderlayRouteSpecR\x04spec\x12K\n\x06status\x18\x03 \x01(\x0b\x32\x33.opi_api.network.cloud.v1alpha1.UnderlayRouteStatusR\x06status:Q\xea\x41N\n,opi_api.network.cloud.v1alpha1/underlayroute\x12\x1eunderlayroutes/{underlayroute}\"\xbc\x03\n\x11UnderlayRouteSpec\x12/\n\x14route_table_name_ref\x18\x01 \x01(\tR\x11routeTableNameRef\x12P\n\x0b\x64\x65st_prefix\x18\x02 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixR\ndestPrefix\x12Z\n\x10next_hop_address\x18\x03 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x0enextHopAddress\x12G\n\x05state\x18\x04 \x01(\x0e\x32\x31.opi_api.network.opinetcommon.v1alpha1.AdminStateR\x05state\x12\x32\n\x15\x65nable_admin_distance\x18\x05 \x01(\x08R\x13\x65nableAdminDistance\x12\x1d\n\nadmin_dist\x18\x06 \x01(\x05R\tadminDist\x12,\n\x12interface_name_ref\x18\x07 \x01(\tR\x10interfaceNameRef\"\xad\x04\n\x13UnderlayRouteStatus\x12/\n\x14route_table_name_ref\x18\x01 \x01(\x05R\x11routeTableNameRef\x12P\n\x0b\x64\x65st_prefix\x18\x02 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixR\ndestPrefix\x12Z\n\x10next_hop_address\x18\x03 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x0enextHopAddress\x12\x19\n\x08if_index\x18\x05 \x01(\x05R\x07ifIndex\x12\x44\n\x04type\x18\x06 \x01(\x0e\x32\x30.opi_api.network.opinetcommon.v1alpha1.RouteTypeR\x04type\x12J\n\x05proto\x18\x07 \x01(\x0e\x32\x34.opi_api.network.opinetcommon.v1alpha1.RouteProtocolR\x05proto\x12\x10\n\x03\x61ge\x18\x08 \x01(\x05R\x03\x61ge\x12\x16\n\x06metric\x18\t \x01(\x05R\x06metric\x12\x1b\n\tfib_route\x18\n \x01(\x08R\x08\x66ibRoute\x12\x1c\n\tconnected\x18\x0b \x01(\x08R\tconnected\x12%\n\x0e\x61\x64min_distance\x18\x0c \x01(\x05R\radminDistance\"\xd7\x02\n\x16UnderlayRouteLookupKey\x12/\n\x14route_table_name_ref\x18\x01 \x01(\tR\x11routeTableNameRef\x12P\n\x0b\x64\x65st_prefix\x18\x02 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixR\ndestPrefix\x12Z\n\x10next_hop_address\x18\x03 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x0enextHopAddress\x12\x12\n\x04ifid\x18\x04 \x01(\x05R\x04ifid\x12J\n\x05proto\x18\x06 \x01(\x0e\x32\x34.opi_api.network.opinetcommon.v1alpha1.RouteProtocolR\x05protoBs\n\x1eopi_api.network.cloud.v1alpha1B\x12UnderlayRouteProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'underlayroute_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\022UnderlayRouteProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_UNDERLAYROUTE']._options = None
  _globals['_UNDERLAYROUTE']._serialized_options = b'\352AN\n,opi_api.network.cloud.v1alpha1/underlayroute\022\036underlayroutes/{underlayroute}'
  _globals['_UNDERLAYROUTE']._serialized_start=103
  _globals['_UNDERLAYROUTE']._serialized_end=369
  _globals['_UNDERLAYROUTESPEC']._serialized_start=372
  _globals['_UNDERLAYROUTESPEC']._serialized_end=816
  _globals['_UNDERLAYROUTESTATUS']._serialized_start=819
  _globals['_UNDERLAYROUTESTATUS']._serialized_end=1376
  _globals['_UNDERLAYROUTELOOKUPKEY']._serialized_start=1379
  _globals['_UNDERLAYROUTELOOKUPKEY']._serialized_end=1722
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: networkinterfaces.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
import networkvlan_pb2 as networkvlan__pb2
import networkethernet_pb2 as networkethernet__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17networkinterfaces.proto\x12%opi_api.network.opinetcommon.v1alpha1\x1a\x12networktypes.proto\x1a\x11networkvlan.proto\x1a\x15networkethernet.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"\xc9\x02\n\x06\x43onfig\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x04name\x12N\n\x04type\x18\x02 \x01(\x0e\x32\x34.opi_api.network.opinetcommon.v1alpha1.InterfaceTypeB\x04\xe2\x41\x01\x02R\x04type\x12\x16\n\x03mtu\x18\x03 \x01(\rB\x04\xe2\x41\x01\x02R\x03mtu\x12)\n\rloopback_mode\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x02R\x0cloopbackMode\x12&\n\x0b\x64\x65scription\x18\x05 \x01(\tB\x04\xe2\x41\x01\x02R\x0b\x64\x65scription\x12\x1e\n\x07\x65nabled\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x02R\x07\x65nabled\x12J\n\x04tpid\x18\x07 \x01(\x0e\x32\x30.opi_api.network.opinetcommon.v1alpha1.TpidTypesB\x04\xe2\x41\x01\x01R\x04tpid\"\x98\x06\n\x08\x43ounters\x12!\n\trx_octets\x18\x01 \x01(\x04\x42\x04\xe2\x41\x01\x03R\x08rxOctets\x12#\n\nrx_packets\x18\x02 \x01(\x04\x42\x04\xe2\x41\x01\x03R\trxPackets\x12,\n\x0frx_unicast_pkts\x18\x03 \x01(\x04\x42\x04\xe2\x41\x01\x03R\rrxUnicastPkts\x12\x30\n\x11rx_broadcast_pkts\x18\x04 \x01(\x04\x42\x04\xe2\x41\x01\x03R\x0frxBroadcastPkts\x12\x30\n\x11rx_multicast_pkts\x18\x05 \x01(\x04\x42\x04\xe2\x41\x01\x03R\x0frxMulticastPkts\x12%\n\x0brx_discards\x18\x06 \x01(\x04\x42\x04\xe2\x41\x01\x03R\nrxDiscards\x12!\n\trx_errors\x18\x07 \x01(\x04\x42\x04\xe2\x41\x01\x03R\x08rxErrors\x12\x30\n\x11rx_unknown_protos\x18\x08 \x01(\x04\x42\x04\xe2\x41\x01\x03R\x0frxUnknownProtos\x12(\n\rrx_fcs_errors\x18\t \x01(\x04\x42\x04\xe2\x41\x01\x03R\x0brxFcsErrors\x12#\n\nout_octets\x18\n \x01(\x04\x42\x04\xe2\x41\x01\x03R\toutOctets\x12%\n\x0bout_packets\x18\x0b \x01(\x04\x42\x04\xe2\x41\x01\x03R\noutPackets\x12.\n\x10out_unicast_pkts\x18\x0c \x01(\x04\x42\x04\xe2\x41\x01\x03R\x0eoutUnicastPkts\x12\x32\n\x12out_broadcast_pkts\x18\r \x01(\x04\x42\x04\xe2\x41\x01\x03R\x10outBroadcastPkts\x12\x32\n\x12out_multicast_pkts\x18\x0e \x01(\x04\x42\x04\xe2\x41\x01\x03R\x10outMulticastPkts\x12\'\n\x0cout_discards\x18\x0f \x01(\x04\x42\x04\xe2\x41\x01\x03R\x0boutDiscards\x12#\n\nout_errors\x18\x10 \x01(\x04\x42\x04\xe2\x41\x01\x03R\toutErrors\x12\x35\n\x13\x63\x61rrier_transitions\x18\x11 \x01(\x04\x42\x04\xe2\x41\x01\x03R\x12\x63\x61rrierTransitions\x12#\n\nlast_clear\x18\x12 \x01(\x04\x42\x04\xe2\x41\x01\x03R\tlastClear\"\xf1\x05\n\x05State\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12N\n\x04type\x18\x02 \x01(\x0e\x32\x34.opi_api.network.opinetcommon.v1alpha1.InterfaceTypeB\x04\xe2\x41\x01\x03R\x04type\x12\x16\n\x03mtu\x18\x03 \x01(\rB\x04\xe2\x41\x01\x03R\x03mtu\x12)\n\rloopback_mode\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x03R\x0cloopbackMode\x12&\n\x0b\x64\x65scription\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x0b\x64\x65scription\x12\x1e\n\x07\x65nabled\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x03R\x07\x65nabled\x12\x1e\n\x07ifindex\x18\x07 \x01(\rB\x04\xe2\x41\x01\x03R\x07ifindex\x12X\n\x0b\x61\x64min_state\x18\x08 \x01(\x0e\x32\x31.opi_api.network.opinetcommon.v1alpha1.AdminStateB\x04\xe2\x41\x01\x03R\nadminState\x12U\n\noper_state\x18\t \x01(\x0e\x32\x30.opi_api.network.opinetcommon.v1alpha1.OperStateB\x04\xe2\x41\x01\x03R\toperState\x12%\n\x0blast_change\x18\n \x01(\x04\x42\x04\xe2\x41\x01\x03R\nlastChange\x12\x1e\n\x07logical\x18\x0b \x01(\x08\x42\x04\xe2\x41\x01\x03R\x07logical\x12$\n\nmanagement\x18\x0c \x01(\x08\x42\x04\xe2\x41\x01\x03R\nmanagement\x12\x16\n\x03\x63pu\x18\r \x01(\x08\x42\x04\xe2\x41\x01\x03R\x03\x63pu\x12Q\n\x08\x63ounters\x18\x0e \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.CountersB\x04\xe2\x41\x01\x03R\x08\x63ounters\x12J\n\x04tpid\x18\x0f \x01(\x0e\x32\x30.opi_api.network.opinetcommon.v1alpha1.TpidTypesB\x04\xe2\x41\x01\x03R\x04tpid\"\xfd\x0b\n\x0cNetInterface\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12K\n\x06\x63onfig\x18\x02 \x01(\x0b\x32-.opi_api.network.opinetcommon.v1alpha1.ConfigB\x04\xe2\x41\x01\x02R\x06\x63onfig\x12H\n\x05state\x18\x03 \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.StateB\x04\xe2\x41\x01\x03R\x05state\x12^\n\x08holdtime\x18\x04 \x01(\x0b\x32<.opi_api.network.opinetcommon.v1alpha1.NetInterface.HoldTimeB\x04\xe2\x41\x01\x01R\x08holdtime\x12m\n\rsubinterfaces\x18\x05 \x01(\x0b\x32\x41.opi_api.network.opinetcommon.v1alpha1.NetInterface.SubinterfacesB\x04\xe2\x41\x01\x01R\rsubinterfaces\x12S\n\x08\x65thernet\x18\x06 \x01(\x0b\x32\x31.opi_api.network.opinetcommon.v1alpha1.EthernetIfB\x04\xe2\x41\x01\x01R\x08\x65thernet\x1a\xe2\x02\n\x08HoldTime\x12n\n\x0bhold_config\x18\x01 \x01(\x0b\x32G.opi_api.network.opinetcommon.v1alpha1.NetInterface.HoldTime.HoldConfigB\x04\xe2\x41\x01\x01R\nholdConfig\x12k\n\nhold_state\x18\x02 \x01(\x0b\x32\x46.opi_api.network.opinetcommon.v1alpha1.NetInterface.HoldTime.HoldStateB\x04\xe2\x41\x01\x03R\tholdState\x1a<\n\nHoldConfig\x12\x14\n\x02up\x18\x01 \x01(\rB\x04\xe2\x41\x01\x01R\x02up\x12\x18\n\x04\x64own\x18\x02 \x01(\rB\x04\xe2\x41\x01\x01R\x04\x64own\x1a;\n\tHoldState\x12\x14\n\x02up\x18\x01 \x01(\rB\x04\xe2\x41\x01\x03R\x02up\x12\x18\n\x04\x64own\x18\x02 \x01(\rB\x04\xe2\x41\x01\x03R\x04\x64own\x1a\xc2\x04\n\rSubinterfaces\x12x\n\x0csubinterface\x18\x02 \x03(\x0b\x32N.opi_api.network.opinetcommon.v1alpha1.NetInterface.Subinterfaces.SubinterfaceB\x04\xe2\x41\x01\x01R\x0csubinterface\x1a\xb6\x03\n\x0cSubinterface\x12\x1a\n\x05index\x18\x01 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x05index\x12\x83\x01\n\x0csubif_config\x18\x02 \x01(\x0b\x32Z.opi_api.network.opinetcommon.v1alpha1.NetInterface.Subinterfaces.Subinterface.SubifConfigB\x04\xe2\x41\x01\x01R\x0bsubifConfig\x12H\n\x05state\x18\x03 \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.StateB\x04\xe2\x41\x01\x03R\x05state\x12G\n\x04vlan\x18\x04 \x01(\x0b\x32-.opi_api.network.opinetcommon.v1alpha1.VlanIfB\x04\xe2\x41\x01\x01R\x04vlan\x1aq\n\x0bSubifConfig\x12\x1a\n\x05index\x18\x01 \x01(\x04\x42\x04\xe2\x41\x01\x01R\x05index\x12&\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0b\x64\x65scription\x12\x1e\n\x07\x65nabled\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x07\x65nabled:n\xea\x41k\n2opi_api.network.opinetcommon.v1alpha1/NetInterface\x12\x18netInterface/{interface}*\rnetInterfaces2\x0cnetInterface\"T\n\x16GetNetInterfaceRequest\x12:\n\x04name\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.network.v1/InterfacesR\x04name\"\xa2\x01\n\x18ListNetInterfacesRequest\x12>\n\x06parent\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.network.v1/InterfacesR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x9f\x01\n\x19ListNetInterfacesResponse\x12Z\n\x0enet_interfaces\x18\x01 \x03(\x0b\x32\x33.opi_api.network.opinetcommon.v1alpha1.NetInterfaceR\rnetInterfaces\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xe9\x01\n\x19UpdateNetInterfaceRequest\x12^\n\rnet_interface\x18\x01 \x01(\x0b\x32\x33.opi_api.network.opinetcommon.v1alpha1.NetInterfaceB\x04\xe2\x41\x01\x02R\x0cnetInterface\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing*i\n\rInterfaceType\x12\x1e\n\x1aINTERFACE_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17INTERFACE_TYPE_ETHERNET\x10\x01\x12\x1b\n\x17INTERFACE_TYPE_LOOPBACK\x10\x02*\xd4\x01\n\tOperState\x12\x1a\n\x16OPER_STATE_UNSPECIFIED\x10\x00\x12\x11\n\rOPER_STATE_UP\x10\x02\x12\x13\n\x0fOPER_STATE_DOWN\x10\x03\x12\x16\n\x12OPER_STATE_TESTING\x10\x04\x12\x16\n\x12OPER_STATE_UNKNOWN\x10\x05\x12\x16\n\x12OPER_STATE_DORMANT\x10\x06\x12\x1a\n\x16OPER_STATE_NOT_PRESENT\x10\x07\x12\x1f\n\x1bOPER_STATE_LOWER_LAYER_DOWN\x10\x08\x32\x88\x05\n\x13NetInterfaceService\x12\xb9\x01\n\x0fGetNetInterface\x12=.opi_api.network.opinetcommon.v1alpha1.GetNetInterfaceRequest\x1a\x33.opi_api.network.opinetcommon.v1alpha1.NetInterface\"2\xda\x41\x04name\x82\xd3\xe4\x93\x02%\x12#/v1/{name=interfaces/*/interface/*}\x12\xc0\x01\n\x11ListNetInterfaces\x12?.opi_api.network.opinetcommon.v1alpha1.ListNetInterfacesRequest\x1a@.opi_api.network.opinetcommon.v1alpha1.ListNetInterfacesResponse\"(\xda\x41\x06parent\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=interfaces}\x12\xf1\x01\n\x12UpdateNetInterface\x12@.opi_api.network.opinetcommon.v1alpha1.UpdateNetInterfaceRequest\x1a\x33.opi_api.network.opinetcommon.v1alpha1.NetInterface\"d\xda\x41\x19net_interface,update_mask\x82\xd3\xe4\x93\x02\x42\x32\x31/v1/{net_interface.name=interfaces/*/interface/*}:\rnet_interfaceB\x85\x01\n%opi_api.network.opinetcommon.v1alpha1B\x16NetworkInterfacesProtoP\x01ZBgithub.com/opiproject/opi-api/network/opinetcommon/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'networkinterfaces_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%opi_api.network.opinetcommon.v1alpha1B\026NetworkInterfacesProtoP\001ZBgithub.com/opiproject/opi-api/network/opinetcommon/v1alpha1/gen/go'
  _globals['_CONFIG'].fields_by_name['name']._options = None
  _globals['_CONFIG'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CONFIG'].fields_by_name['type']._options = None
  _globals['_CONFIG'].fields_by_name['type']._serialized_options = b'\342A\001\002'
  _globals['_CONFIG'].fields_by_name['mtu']._options = None
  _globals['_CONFIG'].fields_by_name['mtu']._serialized_options = b'\342A\001\002'
  _globals['_CONFIG'].fields_by_name['loopback_mode']._options = None
  _globals['_CONFIG'].fields_by_name['loopback_mode']._serialized_options = b'\342A\001\002'
  _globals['_CONFIG'].fields_by_name['description']._options = None
  _globals['_CONFIG'].fields_by_name['description']._serialized_options = b'\342A\001\002'
  _globals['_CONFIG'].fields_by_name['enabled']._options = None
  _globals['_CONFIG'].fields_by_name['enabled']._serialized_options = b'\342A\001\002'
  _globals['_CONFIG'].fields_by_name['tpid']._options = None
  _globals['_CONFIG'].fields_by_name['tpid']._serialized_options = b'\342A\001\001'
  _globals['_COUNTERS'].fields_by_name['rx_octets']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_octets']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_packets']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_packets']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_unicast_pkts']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_unicast_pkts']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_broadcast_pkts']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_broadcast_pkts']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_multicast_pkts']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_multicast_pkts']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_discards']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_discards']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_errors']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_errors']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_unknown_protos']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_unknown_protos']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_fcs_errors']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_fcs_errors']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['out_octets']._options = None
  _globals['_COUNTERS'].fields_by_name['out_octets']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['out_packets']._options = None
  _globals['_COUNTERS'].fields_by_name['out_packets']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['out_unicast_pkts']._options = None
  _globals['_COUNTERS'].fields_by_name['out_unicast_pkts']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['out_broadcast_pkts']._options = None
  _globals['_COUNTERS'].fields_by_name['out_broadcast_pkts']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['out_multicast_pkts']._options = None
  _globals['_COUNTERS'].fields_by_name['out_multicast_pkts']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['out_discards']._options = None
  _globals['_COUNTERS'].fields_by_name['out_discards']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['out_errors']._options = None
  _globals['_COUNTERS'].fields_by_name['out_errors']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['carrier_transitions']._options = None
  _globals['_COUNTERS'].fields_by_name['carrier_transitions']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['last_clear']._options = None
  _globals['_COUNTERS'].fields_by_name['last_clear']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['name']._options = None
  _globals['_STATE'].fields_by_name['name']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['type']._options = None
  _globals['_STATE'].fields_by_name['type']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['mtu']._options = None
  _globals['_STATE'].fields_by_name['mtu']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['loopback_mode']._options = None
  _globals['_STATE'].fields_by_name['loopback_mode']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['description']._options = None
  _globals['_STATE'].fields_by_name['description']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['enabled']._options = None
  _globals['_STATE'].fields_by_name['enabled']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['ifindex']._options = None
  _globals['_STATE'].fields_by_name['ifindex']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['admin_state']._options = None
  _globals['_STATE'].fields_by_name['admin_state']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['oper_state']._options = None
  _globals['_STATE'].fields_by_name['oper_state']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['last_change']._options = None
  _globals['_STATE'].fields_by_name['last_change']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['logical']._options = None
  _globals['_STATE'].fields_by_name['logical']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['management']._options = None
  _globals['_STATE'].fields_by_name['management']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['cpu']._options = None
  _globals['_STATE'].fields_by_name['cpu']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['counters']._options = None
  _globals['_STATE'].fields_by_name['counters']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['tpid']._options = None
  _globals['_STATE'].fields_by_name['tpid']._serialized_options = b'\342A\001\003'
  _globals['_NETINTERFACE_HOLDTIME_HOLDCONFIG'].fields_by_name['up']._options = None
  _globals['_NETINTERFACE_HOLDTIME_HOLDCONFIG'].fields_by_name['up']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_HOLDTIME_HOLDCONFIG'].fields_by_name['down']._options = None
  _globals['_NETINTERFACE_HOLDTIME_HOLDCONFIG'].fields_by_name['down']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_HOLDTIME_HOLDSTATE'].fields_by_name['up']._options = None
  _globals['_NETINTERFACE_HOLDTIME_HOLDSTATE'].fields_by_name['up']._serialized_options = b'\342A\001\003'
  _globals['_NETINTERFACE_HOLDTIME_HOLDSTATE'].fields_by_name['down']._options = None
  _globals['_NETINTERFACE_HOLDTIME_HOLDSTATE'].fields_by_name['down']._serialized_options = b'\342A\001\003'
  _globals['_NETINTERFACE_HOLDTIME'].fields_by_name['hold_config']._options = None
  _globals['_NETINTERFACE_HOLDTIME'].fields_by_name['hold_config']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_HOLDTIME'].fields_by_name['hold_state']._options = None
  _globals['_NETINTERFACE_HOLDTIME'].fields_by_name['hold_state']._serialized_options = b'\342A\001\003'
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG'].fields_by_name['index']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG'].fields_by_name['index']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG'].fields_by_name['description']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG'].fields_by_name['description']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG'].fields_by_name['enabled']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG'].fields_by_name['enabled']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['index']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['index']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['subif_config']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['subif_config']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['state']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['state']._serialized_options = b'\342A\001\003'
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['vlan']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['vlan']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_SUBINTERFACES'].fields_by_name['subinterface']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES'].fields_by_name['subinterface']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE'].fields_by_name['name']._options = None
  _globals['_NETINTERFACE'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NETINTERFACE'].fields_by_name['config']._options = None
  _globals['_NETINTERFACE'].fields_by_name['config']._serialized_options = b'\342A\001\002'
  _globals['_NETINTERFACE'].fields_by_name['state']._options = None
  _globals['_NETINTERFACE'].fields_by_name['state']._serialized_options = b'\342A\001\003'
  _globals['_NETINTERFACE'].fields_by_name['holdtime']._options = None
  _globals['_NETINTERFACE'].fields_by_name['holdtime']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE'].fields_by_name['subinterfaces']._options = None
  _globals['_NETINTERFACE'].fields_by_name['subinterfaces']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE'].fields_by_name['ethernet']._options = None
  _globals['_NETINTERFACE'].fields_by_name['ethernet']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE']._options = None
  _globals['_NETINTERFACE']._serialized_options = b'\352Ak\n2opi_api.network.opinetcommon.v1alpha1/NetInterface\022\030netInterface/{interface}*\rnetInterfaces2\014netInterface'
  _globals['_GETNETINTERFACEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNETINTERFACEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.network.v1/Interfaces'
  _globals['_LISTNETINTERFACESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTNETINTERFACESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.network.v1/Interfaces'
  _globals['_LISTNETINTERFACESREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNETINTERFACESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNETINTERFACESREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNETINTERFACESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENETINTERFACEREQUEST'].fields_by_name['net_interface']._options = None
  _globals['_UPDATENETINTERFACEREQUEST'].fields_by_name['net_interface']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENETINTERFACEREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATENETINTERFACEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENETINTERFACEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATENETINTERFACEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACESERVICE'].methods_by_name['GetNetInterface']._options = None
  _globals['_NETINTERFACESERVICE'].methods_by_name['GetNetInterface']._serialized_options = b'\332A\004name\202\323\344\223\002%\022#/v1/{name=interfaces/*/interface/*}'
  _globals['_NETINTERFACESERVICE'].methods_by_name['ListNetInterfaces']._options = None
  _globals['_NETINTERFACESERVICE'].methods_by_name['ListNetInterfaces']._serialized_options = b'\332A\006parent\202\323\344\223\002\031\022\027/v1/{parent=interfaces}'
  _globals['_NETINTERFACESERVICE'].methods_by_name['UpdateNetInterface']._options = None
  _globals['_NETINTERFACESERVICE'].methods_by_name['UpdateNetInterface']._serialized_options = b'\332A\031net_interface,update_mask\202\323\344\223\002B21/v1/{net_interface.name=interfaces/*/interface/*}:\rnet_interface'
  _globals['_INTERFACETYPE']._serialized_start=4345
  _globals['_INTERFACETYPE']._serialized_end=4450
  _globals['_OPERSTATE']._serialized_start=4453
  _globals['_OPERSTATE']._serialized_end=4665
  _globals['_CONFIG']._serialized_start=278
  _globals['_CONFIG']._serialized_end=607
  _globals['_COUNTERS']._serialized_start=610
  _globals['_COUNTERS']._serialized_end=1402
  _globals['_STATE']._serialized_start=1405
  _globals['_STATE']._serialized_end=2158
  _globals['_NETINTERFACE']._serialized_start=2161
  _globals['_NETINTERFACE']._serialized_end=3694
  _globals['_NETINTERFACE_HOLDTIME']._serialized_start=2647
  _globals['_NETINTERFACE_HOLDTIME']._serialized_end=3001
  _globals['_NETINTERFACE_HOLDTIME_HOLDCONFIG']._serialized_start=2880
  _globals['_NETINTERFACE_HOLDTIME_HOLDCONFIG']._serialized_end=2940
  _globals['_NETINTERFACE_HOLDTIME_HOLDSTATE']._serialized_start=2942
  _globals['_NETINTERFACE_HOLDTIME_HOLDSTATE']._serialized_end=3001
  _globals['_NETINTERFACE_SUBINTERFACES']._serialized_start=3004
  _globals['_NETINTERFACE_SUBINTERFACES']._serialized_end=3582
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE']._serialized_start=3144
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE']._serialized_end=3582
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG']._serialized_start=3469
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG']._serialized_end=3582
  _globals['_GETNETINTERFACEREQUEST']._serialized_start=3696
  _globals['_GETNETINTERFACEREQUEST']._serialized_end=3780
  _globals['_LISTNETINTERFACESREQUEST']._serialized_start=3783
  _globals['_LISTNETINTERFACESREQUEST']._serialized_end=3945
  _globals['_LISTNETINTERFACESRESPONSE']._serialized_start=3948
  _globals['_LISTNETINTERFACESRESPONSE']._serialized_end=4107
  _globals['_UPDATENETINTERFACEREQUEST']._serialized_start=4110
  _globals['_UPDATENETINTERFACEREQUEST']._serialized_end=4343
  _globals['_NETINTERFACESERVICE']._serialized_start=4668
  _globals['_NETINTERFACESERVICE']._serialized_end=5316
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: backend_malloc.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
import opicommon_pb2 as opicommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x62\x61\x63kend_malloc.proto\x12\x12opi_api.storage.v1\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x0fopicommon.proto\"\x96\x02\n\x0cMallocVolume\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12#\n\nblock_size\x18\x02 \x01(\x03\x42\x04\xe2\x41\x01\x02R\tblockSize\x12\'\n\x0c\x62locks_count\x18\x03 \x01(\x03\x42\x04\xe2\x41\x01\x02R\x0b\x62locksCount\x12)\n\rmetadata_size\x18\x04 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0cmetadataSize\x12\x18\n\x04uuid\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01R\x04uuid:Y\xea\x41V\n\x1fopi_api.storage.v1/MallocVolume\x12\x16mallocVolumes/{volume}*\rmallocVolumes2\x0cmallocVolume\"\x98\x01\n\x19\x43reateMallocVolumeRequest\x12K\n\rmalloc_volume\x18\x01 \x01(\x0b\x32 .opi_api.storage.v1.MallocVolumeB\x04\xe2\x41\x01\x02R\x0cmallocVolume\x12.\n\x10malloc_volume_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0emallocVolumeId\"\x84\x01\n\x19\x44\x65leteMallocVolumeRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.storage.v1/MallocVolumeR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xd6\x01\n\x19UpdateMallocVolumeRequest\x12K\n\rmalloc_volume\x18\x01 \x01(\x0b\x32 .opi_api.storage.v1.MallocVolumeB\x04\xe2\x41\x01\x02R\x0cmallocVolume\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"b\n\x18ListMallocVolumesRequest\x12!\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x8c\x01\n\x19ListMallocVolumesResponse\x12G\n\x0emalloc_volumes\x18\x01 \x03(\x0b\x32 .opi_api.storage.v1.MallocVolumeR\rmallocVolumes\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"V\n\x16GetMallocVolumeRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.storage.v1/MallocVolumeR\x04name\"X\n\x18StatsMallocVolumeRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.storage.v1/MallocVolumeR\x04name\"R\n\x19StatsMallocVolumeResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats2\xd5\x07\n\x13MallocVolumeService\x12\xb0\x01\n\x12\x43reateMallocVolume\x12-.opi_api.storage.v1.CreateMallocVolumeRequest\x1a .opi_api.storage.v1.MallocVolume\"I\xda\x41\x1emalloc_volume,malloc_volume_id\x82\xd3\xe4\x93\x02\"\"\x11/v1/mallocVolumes:\rmalloc_volume\x12\x86\x01\n\x12\x44\x65leteMallocVolume\x12-.opi_api.storage.v1.DeleteMallocVolumeRequest\x1a\x16.google.protobuf.Empty\")\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/{name=mallocVolumes/*}\x12\xc2\x01\n\x12UpdateMallocVolume\x12-.opi_api.storage.v1.UpdateMallocVolumeRequest\x1a .opi_api.storage.v1.MallocVolume\"[\xda\x41\x19malloc_volume,update_mask\x82\xd3\xe4\x93\x02\x39\x32(/v1/{malloc_volume.name=mallocVolumes/*}:\rmalloc_volume\x12\x8b\x01\n\x11ListMallocVolumes\x12,.opi_api.storage.v1.ListMallocVolumesRequest\x1a-.opi_api.storage.v1.ListMallocVolumesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/mallocVolumes\x12\x8a\x01\n\x0fGetMallocVolume\x12*.opi_api.storage.v1.GetMallocVolumeRequest\x1a .opi_api.storage.v1.MallocVolume\")\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/{name=mallocVolumes/*}\x12\xa1\x01\n\x11StatsMallocVolume\x12,.opi_api.storage.v1.StatsMallocVolumeRequest\x1a-.opi_api.storage.v1.StatsMallocVolumeResponse\"/\xda\x41\x04name\x82\xd3\xe4\x93\x02\"\x12 /v1/{name=mallocVolumes/*}:statsBa\n\x12opi_api.storage.v1B\x12\x42\x61\x63kendMallocProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'backend_malloc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\022BackendMallocProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_MALLOCVOLUME'].fields_by_name['name']._options = None
  _globals['_MALLOCVOLUME'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_MALLOCVOLUME'].fields_by_name['block_size']._options = None
  _globals['_MALLOCVOLUME'].fields_by_name['block_size']._serialized_options = b'\342A\001\002'
  _globals['_MALLOCVOLUME'].fields_by_name['blocks_count']._options = None
  _globals['_MALLOCVOLUME'].fields_by_name['blocks_count']._serialized_options = b'\342A\001\002'
  _globals['_MALLOCVOLUME'].fields_by_name['metadata_size']._options = None
  _globals['_MALLOCVOLUME'].fields_by_name['metadata_size']._serialized_options = b'\342A\001\001'
  _globals['_MALLOCVOLUME'].fields_by_name['uuid']._options = None
  _globals['_MALLOCVOLUME'].fields_by_name['uuid']._serialized_options = b'\342A\001\001'
  _globals['_MALLOCVOLUME']._options = None
  _globals['_MALLOCVOLUME']._serialized_options = b'\352AV\n\037opi_api.storage.v1/MallocVolume\022\026mallocVolumes/{volume}*\rmallocVolumes2\014mallocVolume'
  _globals['_CREATEMALLOCVOLUMEREQUEST'].fields_by_name['malloc_volume']._options = None
  _globals['_CREATEMALLOCVOLUMEREQUEST'].fields_by_name['malloc_volume']._serialized_options = b'\342A\001\002'
  _globals['_CREATEMALLOCVOLUMEREQUEST'].fields_by_name['malloc_volume_id']._options = None
  _globals['_CREATEMALLOCVOLUMEREQUEST'].fields_by_name['malloc_volume_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEMALLOCVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEMALLOCVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.storage.v1/MallocVolume'
  _globals['_DELETEMALLOCVOLUMEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEMALLOCVOLUMEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEMALLOCVOLUMEREQUEST'].fields_by_name['malloc_volume']._options = None
  _globals['_UPDATEMALLOCVOLUMEREQUEST'].fields_by_name['malloc_volume']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEMALLOCVOLUMEREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEMALLOCVOLUMEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEMALLOCVOLUMEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEMALLOCVOLUMEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTMALLOCVOLUMESREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTMALLOCVOLUMESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTMALLOCVOLUMESREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTMALLOCVOLUMESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETMALLOCVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETMALLOCVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.storage.v1/MallocVolume'
  _globals['_STATSMALLOCVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSMALLOCVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.storage.v1/MallocVolume'
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['CreateMallocVolume']._options = None
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['CreateMallocVolume']._serialized_options = b'\332A\036malloc_volume,malloc_volume_id\202\323\344\223\002\"\"\021/v1/mallocVolumes:\rmalloc_volume'
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['DeleteMallocVolume']._options = None
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['DeleteMallocVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\034*\032/v1/{name=mallocVolumes/*}'
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['UpdateMallocVolume']._options = None
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['UpdateMallocVolume']._serialized_options = b'\332A\031malloc_volume,update_mask\202\323\344\223\00292(/v1/{malloc_volume.name=mallocVolumes/*}:\rmalloc_volume'
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['ListMallocVolumes']._options = None
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['ListMallocVolumes']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/mallocVolumes'
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['GetMallocVolume']._options = None
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['GetMallocVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\034\022\032/v1/{name=mallocVolumes/*}'
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['StatsMallocVolume']._options = None
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['StatsMallocVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\"\022 /v1/{name=mallocVolumes/*}:stats'
  _globals['_MALLOCVOLUME']._serialized_start=240
  _globals['_MALLOCVOLUME']._serialized_end=518
  _globals['_CREATEMALLOCVOLUMEREQUEST']._serialized_start=521
  _globals['_CREATEMALLOCVOLUMEREQUEST']._serialized_end=673
  _globals['_DELETEMALLOCVOLUMEREQUEST']._serialized_start=676
  _globals['_DELETEMALLOCVOLUMEREQUEST']._serialized_end=808
  _globals['_UPDATEMALLOCVOLUMEREQUEST']._serialized_start=811
  _globals['_UPDATEMALLOCVOLUMEREQUEST']._serialized_end=1025
  _globals['_LISTMALLOCVOLUMESREQUEST']._serialized_start=1027
  _globals['_LISTMALLOCVOLUMESREQUEST']._serialized_end=1125
  _globals['_LISTMALLOCVOLUMESRESPONSE']._serialized_start=1128
  _globals['_LISTMALLOCVOLUMESRESPONSE']._serialized_end=1268
  _globals['_GETMALLOCVOLUMEREQUEST']._serialized_start=1270
  _globals['_GETMALLOCVOLUMEREQUEST']._serialized_end=1356
  _globals['_STATSMALLOCVOLUMEREQUEST']._serialized_start=1358
  _globals['_STATSMALLOCVOLUMEREQUEST']._serialized_end=1446
  _globals['_STATSMALLOCVOLUMERESPONSE']._serialized_start=1448
  _globals['_STATSMALLOCVOLUMERESPONSE']._serialized_end=1530
  _globals['_MALLOCVOLUMESERVICE']._serialized_start=1533
  _globals['_MALLOCVOLUMESERVICE']._serialized_end=2514
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: backend_aio.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
import opicommon_pb2 as opicommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x62\x61\x63kend_aio.proto\x12\x12opi_api.storage.v1\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x0fopicommon.proto\"\xfe\x01\n\tAioVolume\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12#\n\nblock_size\x18\x02 \x01(\x03\x42\x04\xe2\x41\x01\x01R\tblockSize\x12\'\n\x0c\x62locks_count\x18\x03 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0b\x62locksCount\x12\x18\n\x04uuid\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01R\x04uuid\x12 \n\x08\x66ilename\x18\x05 \x01(\tB\x04\xe2\x41\x01\x02R\x08\x66ilename:M\xea\x41J\n\x1copi_api.storage.v1/AioVolume\x12\x13\x61ioVolumes/{volume}*\naioVolumes2\taioVolume\"\x86\x01\n\x16\x43reateAioVolumeRequest\x12\x42\n\naio_volume\x18\x01 \x01(\x0b\x32\x1d.opi_api.storage.v1.AioVolumeB\x04\xe2\x41\x01\x02R\taioVolume\x12(\n\raio_volume_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0b\x61ioVolumeId\"~\n\x16\x44\x65leteAioVolumeRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/AioVolumeR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xca\x01\n\x16UpdateAioVolumeRequest\x12\x42\n\naio_volume\x18\x01 \x01(\x0b\x32\x1d.opi_api.storage.v1.AioVolumeB\x04\xe2\x41\x01\x02R\taioVolume\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"_\n\x15ListAioVolumesRequest\x12!\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x80\x01\n\x16ListAioVolumesResponse\x12>\n\x0b\x61io_volumes\x18\x01 \x03(\x0b\x32\x1d.opi_api.storage.v1.AioVolumeR\naioVolumes\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"P\n\x13GetAioVolumeRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/AioVolumeR\x04name\"R\n\x15StatsAioVolumeRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/AioVolumeR\x04name\"O\n\x16StatsAioVolumeResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats2\xf8\x06\n\x10\x41ioVolumeService\x12\x9b\x01\n\x0f\x43reateAioVolume\x12*.opi_api.storage.v1.CreateAioVolumeRequest\x1a\x1d.opi_api.storage.v1.AioVolume\"=\xda\x41\x18\x61io_volume,aio_volume_id\x82\xd3\xe4\x93\x02\x1c\"\x0e/v1/aioVolumes:\naio_volume\x12}\n\x0f\x44\x65leteAioVolume\x12*.opi_api.storage.v1.DeleteAioVolumeRequest\x1a\x16.google.protobuf.Empty\"&\xda\x41\x04name\x82\xd3\xe4\x93\x02\x19*\x17/v1/{name=aioVolumes/*}\x12\xad\x01\n\x0fUpdateAioVolume\x12*.opi_api.storage.v1.UpdateAioVolumeRequest\x1a\x1d.opi_api.storage.v1.AioVolume\"O\xda\x41\x16\x61io_volume,update_mask\x82\xd3\xe4\x93\x02\x30\x32\"/v1/{aio_volume.name=aioVolumes/*}:\naio_volume\x12\x7f\n\x0eListAioVolumes\x12).opi_api.storage.v1.ListAioVolumesRequest\x1a*.opi_api.storage.v1.ListAioVolumesResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/aioVolumes\x12~\n\x0cGetAioVolume\x12\'.opi_api.storage.v1.GetAioVolumeRequest\x1a\x1d.opi_api.storage.v1.AioVolume\"&\xda\x41\x04name\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{name=aioVolumes/*}\x12\x95\x01\n\x0eStatsAioVolume\x12).opi_api.storage.v1.StatsAioVolumeRequest\x1a*.opi_api.storage.v1.StatsAioVolumeResponse\",\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/{name=aioVolumes/*}:statsB^\n\x12opi_api.storage.v1B\x0f\x42\x61\x63kendAioProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'backend_aio_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\017BackendAioProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_AIOVOLUME'].fields_by_name['name']._options = None
  _globals['_AIOVOLUME'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_AIOVOLUME'].fields_by_name['block_size']._options = None
  _globals['_AIOVOLUME'].fields_by_name['block_size']._serialized_options = b'\342A\001\001'
  _globals['_AIOVOLUME'].fields_by_name['blocks_count']._options = None
  _globals['_AIOVOLUME'].fields_by_name['blocks_count']._serialized_options = b'\342A\001\001'
  _globals['_AIOVOLUME'].fields_by_name['uuid']._options = None
  _globals['_AIOVOLUME'].fields_by_name['uuid']._serialized_options = b'\342A\001\001'
  _globals['_AIOVOLUME'].fields_by_name['filename']._options = None
  _globals['_AIOVOLUME'].fields_by_name['filename']._serialized_options = b'\342A\001\002'
  _globals['_AIOVOLUME']._options = None
  _globals['_AIOVOLUME']._serialized_options = b'\352AJ\n\034opi_api.storage.v1/AioVolume\022\023aioVolumes/{volume}*\naioVolumes2\taioVolume'
  _globals['_CREATEAIOVOLUMEREQUEST'].fields_by_name['aio_volume']._options = None
  _globals['_CREATEAIOVOLUMEREQUEST'].fields_by_name['aio_volume']._serialized_options = b'\342A\001\002'
  _globals['_CREATEAIOVOLUMEREQUEST'].fields_by_name['aio_volume_id']._options = None
  _globals['_CREATEAIOVOLUMEREQUEST'].fields_by_name['aio_volume_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEAIOVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEAIOVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.storage.v1/AioVolume'
  _globals['_DELETEAIOVOLUMEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEAIOVOLUMEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEAIOVOLUMEREQUEST'].fields_by_name['aio_volume']._options = None
  _globals['_UPDATEAIOVOLUMEREQUEST'].fields_by_name['aio_volume']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEAIOVOLUMEREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEAIOVOLUMEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEAIOVOLUMEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEAIOVOLUMEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTAIOVOLUMESREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTAIOVOLUMESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTAIOVOLUMESREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTAIOVOLUMESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETAIOVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETAIOVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.storage.v1/AioVolume'
  _globals['_STATSAIOVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSAIOVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.storage.v1/AioVolume'
  _globals['_AIOVOLUMESERVICE'].methods_by_name['CreateAioVolume']._options = None
  _globals['_AIOVOLUMESERVICE'].methods_by_name['CreateAioVolume']._serialized_options = b'\332A\030aio_volume,aio_volume_id\202\323\344\223\002\034\"\016/v1/aioVolumes:\naio_volume'
  _globals['_AIOVOLUMESERVICE'].methods_by_name['DeleteAioVolume']._options = None
  _globals['_AIOVOLUMESERVICE'].methods_by_name['DeleteAioVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\031*\027/v1/{name=aioVolumes/*}'
  _globals['_AIOVOLUMESERVICE'].methods_by_name['UpdateAioVolume']._options = None
  _globals['_AIOVOLUMESERVICE'].methods_by_name['UpdateAioVolume']._serialized_options = b'\332A\026aio_volume,update_mask\202\323\344\223\00202\"/v1/{aio_volume.name=aioVolumes/*}:\naio_volume'
  _globals['_AIOVOLUMESERVICE'].methods_by_name['ListAioVolumes']._options = None
  _globals['_AIOVOLUMESERVICE'].methods_by_name['ListAioVolumes']._serialized_options = b'\202\323\344\223\002\020\022\016/v1/aioVolumes'
  _globals['_AIOVOLUMESERVICE'].methods_by_name['GetAioVolume']._options = None
  _globals['_AIOVOLUMESERVICE'].methods_by_name['GetAioVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\031\022\027/v1/{name=aioVolumes/*}'
  _globals['_AIOVOLUMESERVICE'].methods_by_name['StatsAioVolume']._options = None
  _globals['_AIOVOLUMESERVICE'].methods_by_name['StatsAioVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\037\022\035/v1/{name=aioVolumes/*}:stats'
  _globals['_AIOVOLUME']._serialized_start=237
  _globals['_AIOVOLUME']._serialized_end=491
  _globals['_CREATEAIOVOLUMEREQUEST']._serialized_start=494
  _globals['_CREATEAIOVOLUMEREQUEST']._serialized_end=628
  _globals['_DELETEAIOVOLUMEREQUEST']._serialized_start=630
  _globals['_DELETEAIOVOLUMEREQUEST']._serialized_end=756
  _globals['_UPDATEAIOVOLUMEREQUEST']._serialized_start=759
  _globals['_UPDATEAIOVOLUMEREQUEST']._serialized_end=961
  _globals['_LISTAIOVOLUMESREQUEST']._serialized_start=963
  _globals['_LISTAIOVOLUMESREQUEST']._serialized_end=1058
  _globals['_LISTAIOVOLUMESRESPONSE']._serialized_start=1061
  _globals['_LISTAIOVOLUMESRESPONSE']._serialized_end=1189
  _globals['_GETAIOVOLUMEREQUEST']._serialized_start=1191
  _globals['_GETAIOVOLUMEREQUEST']._serialized_end=1271
  _globals['_STATSAIOVOLUMEREQUEST']._serialized_start=1273
  _globals['_STATSAIOVOLUMEREQUEST']._serialized_end=1355
  _globals['_STATSAIOVOLUMERESPONSE']._serialized_start=1357
  _globals['_STATSAIOVOLUMERESPONSE']._serialized_end=1436
  _globals['_AIOVOLUMESERVICE']._serialized_start=1439
  _globals['_AIOVOLUMESERVICE']._serialized_end=2327
# @@protoc_insertion_point(module_scope)



# SPDX-License-Identifier: Apache-2.0
# Copyright (c) 2022 Dell Inc, or its subsidiaries.

import grpc

from .proto.v1 import (
    l2_xpu_infra_mgr_pb2,
    l2_xpu_infra_mgr_pb2_grpc,
    l3_xpu_infra_mgr_pb2,
    l3_xpu_infra_mgr_pb2_grpc,
)


def bridge_create(address):
    try:
        with grpc.insecure_channel(address) as channel:
            stub = l2_xpu_infra_mgr_pb2_grpc.LogicalBridgeServiceStub(channel)
            res = stub.CreateLogicalBridge(
                request=l2_xpu_infra_mgr_pb2.CreateLogicalBridgeRequest()
            )
            return res
    except grpc.RpcError as e:
        print(e)


def port_create(address):
    try:
        with grpc.insecure_channel(address) as channel:
            stub = l2_xpu_infra_mgr_pb2_grpc.BridgePortServiceStub(channel)
            res = stub.CreateBridgePort(
                request=l2_xpu_infra_mgr_pb2.CreateBridgePortRequest()
            )
            return res
    except grpc.RpcError as e:
        print(e)


def vrf_create(address):
    try:
        with grpc.insecure_channel(address) as channel:
            stub = l3_xpu_infra_mgr_pb2_grpc.VrfServiceStub(channel)
            res = stub.CreateVrf(request=l3_xpu_infra_mgr_pb2.CreateVrfRequest())
            return res
    except grpc.RpcError as e:
        print(e)


def svi_create(address):
    try:
        with grpc.insecure_channel(address) as channel:
            stub = l3_xpu_infra_mgr_pb2_grpc.SviServiceStub(channel)
            res = stub.CreateSvi(request=l3_xpu_infra_mgr_pb2.CreateSviRequest())
            return res
    except grpc.RpcError as e:
        print(e)



import logging

import redfish


class CertificateService:
    def __init__(self, host, user, password, **kwargs):
        """
        Create a new connection to DPU via Redfish.
        Due to timeout restrictions, every command will start its own session
        and tear it down once it completes.
        """
        self.logger = logging.getLogger("dpuredfish")
        self._host = host
        self._user = user
        self._password = password
        self.logger.info("Connecting to %s", host)
        self._session = redfish.redfish_client(
            base_url=self._host,
            username=self._user,
            password=self._password,
            cafile=None,
            capath=None,
            max_retry=3,
            timeout=120,
            **kwargs
        )

    def get_certificates(self):
        self.logger.info("Getting Certificates...")
        # TODO: create decorator for login/logout
        self._session.login(auth=redfish.AuthMethod.SESSION)
        response = self._session.get(
            "/redfish/v1/CertificateService/CertificateLocations?$expand=~($levels=1)"
        )
        self.logger.debug(response.text)
        self._session.logout()
        for ch in response.obj.Links.Certificates:
            yield ch



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: backend_nvme.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
import opicommon_pb2 as opicommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x62\x61\x63kend_nvme.proto\x12\x12opi_api.storage.v1\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x0fopicommon.proto\"\x84\x03\n\x14NvmeRemoteController\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12\x45\n\tmultipath\x18\x02 \x01(\x0e\x32!.opi_api.storage.v1.NvmeMultipathB\x04\xe2\x41\x01\x02R\tmultipath\x12,\n\x0fio_queues_count\x18\x03 \x01(\x03\x42\x04\xe2\x41\x01\x01R\rioQueuesCount\x12#\n\nqueue_size\x18\x04 \x01(\x03\x42\x04\xe2\x41\x01\x01R\tqueueSize\x12\x39\n\x03tcp\x18\x05 \x01(\x0b\x32!.opi_api.storage.v1.TcpControllerB\x04\xe2\x41\x01\x01R\x03tcp:}\xea\x41z\n\'opi_api.storage.v1/NvmeRemoteController\x12\"nvmeRemoteControllers/{controller}*\x15nvmeRemoteControllers2\x14nvmeRemoteController\"_\n\rTcpController\x12\x1a\n\x05hdgst\x18\x01 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x05hdgst\x12\x1a\n\x05\x64\x64gst\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x05\x64\x64gst\x12\x16\n\x03psk\x18\x03 \x01(\x0c\x42\x04\xe2\x41\x01\x01R\x03psk\"\xb4\x02\n\x08NvmePath\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12\x43\n\x06trtype\x18\x02 \x01(\x0e\x32%.opi_api.storage.v1.NvmeTransportTypeB\x04\xe2\x41\x01\x02R\x06trtype\x12\x1c\n\x06traddr\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x06traddr\x12?\n\x07\x66\x61\x62rics\x18\x04 \x01(\x0b\x32\x1f.opi_api.storage.v1.FabricsPathB\x04\xe2\x41\x01\x01R\x07\x66\x61\x62rics:j\xea\x41g\n\x1bopi_api.storage.v1/NvmePath\x12\x33nvmeRemoteControllers/{controller}/nvmePaths/{path}*\tnvmePaths2\x08nvmePath\"\x88\x02\n\x0b\x46\x61\x62ricsPath\x12\x1e\n\x07trsvcid\x18\x01 \x01(\x03\x42\x04\xe2\x41\x01\x02R\x07trsvcid\x12\x1c\n\x06subnqn\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x06subnqn\x12\x43\n\x06\x61\x64rfam\x18\x03 \x01(\x0e\x32%.opi_api.storage.v1.NvmeAddressFamilyB\x04\xe2\x41\x01\x02R\x06\x61\x64rfam\x12)\n\rsource_traddr\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01R\x0csourceTraddr\x12+\n\x0esource_trsvcid\x18\x05 \x01(\x03\x42\x04\xe2\x41\x01\x01R\rsourceTrsvcid\x12\x1e\n\x07hostnqn\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01R\x07hostnqn\"\xba\x02\n\x13NvmeRemoteNamespace\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12\x18\n\x04nsid\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x04nsid\x12\x1a\n\x05nguid\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x05nguid\x12\x1a\n\x05\x65ui64\x18\x04 \x01(\x03\x42\x04\xe2\x41\x01\x03R\x05\x65ui64\x12\x18\n\x04uuid\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x04uuid:\x9c\x01\xea\x41\x98\x01\n&opi_api.storage.v1/NvmeRemoteNamespace\x12\x43nvmeRemoteControllers/{controller}/nvmeRemoteNamespaces/{namespace}*\x14nvmeRemoteNamespaces2\x13nvmeRemoteNamespace\"\xca\x01\n!CreateNvmeRemoteControllerRequest\x12\x64\n\x16nvme_remote_controller\x18\x01 \x01(\x0b\x32(.opi_api.storage.v1.NvmeRemoteControllerB\x04\xe2\x41\x01\x02R\x14nvmeRemoteController\x12?\n\x19nvme_remote_controller_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x16nvmeRemoteControllerId\"\x94\x01\n!DeleteNvmeRemoteControllerRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/NvmeRemoteControllerR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xf7\x01\n!UpdateNvmeRemoteControllerRequest\x12\x64\n\x16nvme_remote_controller\x18\x01 \x01(\x0b\x32(.opi_api.storage.v1.NvmeRemoteControllerB\x04\xe2\x41\x01\x02R\x14nvmeRemoteController\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"j\n ListNvmeRemoteControllersRequest\x12!\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\xad\x01\n!ListNvmeRemoteControllersResponse\x12`\n\x17nvme_remote_controllers\x18\x01 \x03(\x0b\x32(.opi_api.storage.v1.NvmeRemoteControllerR\x15nvmeRemoteControllers\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"f\n\x1eGetNvmeRemoteControllerRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/NvmeRemoteControllerR\x04name\"h\n ResetNvmeRemoteControllerRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/NvmeRemoteControllerR\x04name\"h\n StatsNvmeRemoteControllerRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/NvmeRemoteControllerR\x04name\"Z\n!StatsNvmeRemoteControllerResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats\"\xb2\x01\n\x1fListNvmeRemoteNamespacesRequest\x12G\n\x06parent\x18\x01 \x01(\tB/\xe2\x41\x01\x02\xfa\x41(\x12&opi_api.storage.v1/NvmeRemoteNamespaceR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\xa9\x01\n ListNvmeRemoteNamespacesResponse\x12]\n\x16nvme_remote_namespaces\x18\x01 \x03(\x0b\x32\'.opi_api.storage.v1.NvmeRemoteNamespaceR\x14nvmeRemoteNamespaces\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"d\n\x1dGetNvmeRemoteNamespaceRequest\x12\x43\n\x04name\x18\x01 \x01(\tB/\xe2\x41\x01\x02\xfa\x41(\n&opi_api.storage.v1/NvmeRemoteNamespaceR\x04name\"\xca\x01\n\x15\x43reateNvmePathRequest\x12H\n\x06parent\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/NvmeRemoteControllerR\x06parent\x12?\n\tnvme_path\x18\x02 \x01(\x0b\x32\x1c.opi_api.storage.v1.NvmePathB\x04\xe2\x41\x01\x02R\x08nvmePath\x12&\n\x0cnvme_path_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\nnvmePathId\"|\n\x15\x44\x65leteNvmePathRequest\x12\x38\n\x04name\x18\x01 \x01(\tB$\xe2\x41\x01\x02\xfa\x41\x1d\n\x1bopi_api.storage.v1/NvmePathR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xc6\x01\n\x15UpdateNvmePathRequest\x12?\n\tnvme_path\x18\x01 \x01(\x0b\x32\x1c.opi_api.storage.v1.NvmePathB\x04\xe2\x41\x01\x02R\x08nvmePath\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\x9c\x01\n\x14ListNvmePathsRequest\x12<\n\x06parent\x18\x01 \x01(\tB$\xe2\x41\x01\x02\xfa\x41\x1d\x12\x1bopi_api.storage.v1/NvmePathR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"|\n\x15ListNvmePathsResponse\x12;\n\nnvme_paths\x18\x01 \x03(\x0b\x32\x1c.opi_api.storage.v1.NvmePathR\tnvmePaths\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"N\n\x12GetNvmePathRequest\x12\x38\n\x04name\x18\x01 \x01(\tB$\xe2\x41\x01\x02\xfa\x41\x1d\n\x1bopi_api.storage.v1/NvmePathR\x04name\"P\n\x14StatsNvmePathRequest\x12\x38\n\x04name\x18\x01 \x01(\tB$\xe2\x41\x01\x02\xfa\x41\x1d\n\x1bopi_api.storage.v1/NvmePathR\x04name\"N\n\x15StatsNvmePathResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats*\x86\x01\n\rNvmeMultipath\x12\x1e\n\x1aNVME_MULTIPATH_UNSPECIFIED\x10\x00\x12\x1a\n\x16NVME_MULTIPATH_DISABLE\x10\x01\x12\x1b\n\x17NVME_MULTIPATH_FAILOVER\x10\x02\x12\x1c\n\x18NVME_MULTIPATH_MULTIPATH\x10\x03\x32\x86\x16\n\x1bNvmeRemoteControllerService\x12\xeb\x01\n\x1a\x43reateNvmeRemoteController\x12\x35.opi_api.storage.v1.CreateNvmeRemoteControllerRequest\x1a(.opi_api.storage.v1.NvmeRemoteController\"l\xda\x41\x30nvme_remote_controller,nvme_remote_controller_id\x82\xd3\xe4\x93\x02\x33\"\x19/v1/nvmeRemoteControllers:\x16nvme_remote_controller\x12\x9e\x01\n\x1a\x44\x65leteNvmeRemoteController\x12\x35.opi_api.storage.v1.DeleteNvmeRemoteControllerRequest\x1a\x16.google.protobuf.Empty\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$*\"/v1/{name=nvmeRemoteControllers/*}\x12\xfd\x01\n\x1aUpdateNvmeRemoteController\x12\x35.opi_api.storage.v1.UpdateNvmeRemoteControllerRequest\x1a(.opi_api.storage.v1.NvmeRemoteController\"~\xda\x41\"nvme_remote_controller,update_mask\x82\xd3\xe4\x93\x02S29/v1/{nvme_remote_controller.name=nvmeRemoteControllers/*}:\x16nvme_remote_controller\x12\xab\x01\n\x19ListNvmeRemoteControllers\x12\x34.opi_api.storage.v1.ListNvmeRemoteControllersRequest\x1a\x35.opi_api.storage.v1.ListNvmeRemoteControllersResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/nvmeRemoteControllers\x12\xaa\x01\n\x17GetNvmeRemoteController\x12\x32.opi_api.storage.v1.GetNvmeRemoteControllerRequest\x1a(.opi_api.storage.v1.NvmeRemoteController\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$\x12\"/v1/{name=nvmeRemoteControllers/*}\x12\xa5\x01\n\x19ResetNvmeRemoteController\x12\x34.opi_api.storage.v1.ResetNvmeRemoteControllerRequest\x1a\x16.google.protobuf.Empty\":\xda\x41\x04name\x82\xd3\xe4\x93\x02-\"(/v1/{name=nvmeRemoteControllers/*}:reset:\x01*\x12\xc1\x01\n\x19StatsNvmeRemoteController\x12\x34.opi_api.storage.v1.StatsNvmeRemoteControllerRequest\x1a\x35.opi_api.storage.v1.StatsNvmeRemoteControllerResponse\"7\xda\x41\x04name\x82\xd3\xe4\x93\x02*\x12(/v1/{name=nvmeRemoteControllers/*}:stats\x12\xd1\x01\n\x18ListNvmeRemoteNamespaces\x12\x33.opi_api.storage.v1.ListNvmeRemoteNamespacesRequest\x1a\x34.opi_api.storage.v1.ListNvmeRemoteNamespacesResponse\"J\xda\x41\x06parent\x82\xd3\xe4\x93\x02;\x12\x39/v1/{parent=nvmeRemoteControllers/*}/nvmeRemoteNamespaces\x12\xbe\x01\n\x16GetNvmeRemoteNamespace\x12\x31.opi_api.storage.v1.GetNvmeRemoteNamespaceRequest\x1a\'.opi_api.storage.v1.NvmeRemoteNamespace\"H\xda\x41\x04name\x82\xd3\xe4\x93\x02;\x12\x39/v1/{name=nvmeRemoteControllers/*/nvmeRemoteNamespaces/*}\x12\xbc\x01\n\x0e\x43reateNvmePath\x12).opi_api.storage.v1.CreateNvmePathRequest\x1a\x1c.opi_api.storage.v1.NvmePath\"a\xda\x41\x1dparent,nvme_path,nvme_path_id\x82\xd3\xe4\x93\x02;\"./v1/{parent=nvmeRemoteControllers/*}/nvmePaths:\tnvme_path\x12\x92\x01\n\x0e\x44\x65leteNvmePath\x12).opi_api.storage.v1.DeleteNvmePathRequest\x1a\x16.google.protobuf.Empty\"=\xda\x41\x04name\x82\xd3\xe4\x93\x02\x30*./v1/{name=nvmeRemoteControllers/*/nvmePaths/*}\x12\xbe\x01\n\x0eUpdateNvmePath\x12).opi_api.storage.v1.UpdateNvmePathRequest\x1a\x1c.opi_api.storage.v1.NvmePath\"c\xda\x41\x15nvme_path,update_mask\x82\xd3\xe4\x93\x02\x45\x32\x38/v1/{nvme_path.name=nvmeRemoteControllers/*/nvmePaths/*}:\tnvme_path\x12\xa5\x01\n\rListNvmePaths\x12(.opi_api.storage.v1.ListNvmePathsRequest\x1a).opi_api.storage.v1.ListNvmePathsResponse\"?\xda\x41\x06parent\x82\xd3\xe4\x93\x02\x30\x12./v1/{parent=nvmeRemoteControllers/*}/nvmePaths\x12\x92\x01\n\x0bGetNvmePath\x12&.opi_api.storage.v1.GetNvmePathRequest\x1a\x1c.opi_api.storage.v1.NvmePath\"=\xda\x41\x04name\x82\xd3\xe4\x93\x02\x30\x12./v1/{name=nvmeRemoteControllers/*/nvmePaths/*}\x12\xa9\x01\n\rStatsNvmePath\x12(.opi_api.storage.v1.StatsNvmePathRequest\x1a).opi_api.storage.v1.StatsNvmePathResponse\"C\xda\x41\x04name\x82\xd3\xe4\x93\x02\x36\x12\x34/v1/{name=nvmeRemoteControllers/*/nvmePaths/*}:statsB_\n\x12opi_api.storage.v1B\x10\x42\x61\x63kendNvmeProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'backend_nvme_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\020BackendNvmeProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['name']._options = None
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['multipath']._options = None
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['multipath']._serialized_options = b'\342A\001\002'
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['io_queues_count']._options = None
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['io_queues_count']._serialized_options = b'\342A\001\001'
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['queue_size']._options = None
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['queue_size']._serialized_options = b'\342A\001\001'
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['tcp']._options = None
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['tcp']._serialized_options = b'\342A\001\001'
  _globals['_NVMEREMOTECONTROLLER']._options = None
  _globals['_NVMEREMOTECONTROLLER']._serialized_options = b'\352Az\n\'opi_api.storage.v1/NvmeRemoteController\022\"nvmeRemoteControllers/{controller}*\025nvmeRemoteControllers2\024nvmeRemoteController'
  _globals['_TCPCONTROLLER'].fields_by_name['hdgst']._options = None
  _globals['_TCPCONTROLLER'].fields_by_name['hdgst']._serialized_options = b'\342A\001\001'
  _globals['_TCPCONTROLLER'].fields_by_name['ddgst']._options = None
  _globals['_TCPCONTROLLER'].fields_by_name['ddgst']._serialized_options = b'\342A\001\001'
  _globals['_TCPCONTROLLER'].fields_by_name['psk']._options = None
  _globals['_TCPCONTROLLER'].fields_by_name['psk']._serialized_options = b'\342A\001\001'
  _globals['_NVMEPATH'].fields_by_name['name']._options = None
  _globals['_NVMEPATH'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NVMEPATH'].fields_by_name['trtype']._options = None
  _globals['_NVMEPATH'].fields_by_name['trtype']._serialized_options = b'\342A\001\002'
  _globals['_NVMEPATH'].fields_by_name['traddr']._options = None
  _globals['_NVMEPATH'].fields_by_name['traddr']._serialized_options = b'\342A\001\002'
  _globals['_NVMEPATH'].fields_by_name['fabrics']._options = None
  _globals['_NVMEPATH'].fields_by_name['fabrics']._serialized_options = b'\342A\001\001'
  _globals['_NVMEPATH']._options = None
  _globals['_NVMEPATH']._serialized_options = b'\352Ag\n\033opi_api.storage.v1/NvmePath\0223nvmeRemoteControllers/{controller}/nvmePaths/{path}*\tnvmePaths2\010nvmePath'
  _globals['_FABRICSPATH'].fields_by_name['trsvcid']._options = None
  _globals['_FABRICSPATH'].fields_by_name['trsvcid']._serialized_options = b'\342A\001\002'
  _globals['_FABRICSPATH'].fields_by_name['subnqn']._options = None
  _globals['_FABRICSPATH'].fields_by_name['subnqn']._serialized_options = b'\342A\001\002'
  _globals['_FABRICSPATH'].fields_by_name['adrfam']._options = None
  _globals['_FABRICSPATH'].fields_by_name['adrfam']._serialized_options = b'\342A\001\002'
  _globals['_FABRICSPATH'].fields_by_name['source_traddr']._options = None
  _globals['_FABRICSPATH'].fields_by_name['source_traddr']._serialized_options = b'\342A\001\001'
  _globals['_FABRICSPATH'].fields_by_name['source_trsvcid']._options = None
  _globals['_FABRICSPATH'].fields_by_name['source_trsvcid']._serialized_options = b'\342A\001\001'
  _globals['_FABRICSPATH'].fields_by_name['hostnqn']._options = None
  _globals['_FABRICSPATH'].fields_by_name['hostnqn']._serialized_options = b'\342A\001\001'
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['name']._options = None
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['nsid']._options = None
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['nsid']._serialized_options = b'\342A\001\003'
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['nguid']._options = None
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['nguid']._serialized_options = b'\342A\001\003'
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['eui64']._options = None
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['eui64']._serialized_options = b'\342A\001\003'
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['uuid']._options = None
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['uuid']._serialized_options = b'\342A\001\003'
  _globals['_NVMEREMOTENAMESPACE']._options = None
  _globals['_NVMEREMOTENAMESPACE']._serialized_options = b'\352A\230\001\n&opi_api.storage.v1/NvmeRemoteNamespace\022CnvmeRemoteControllers/{controller}/nvmeRemoteNamespaces/{namespace}*\024nvmeRemoteNamespaces2\023nvmeRemoteNamespace'
  _globals['_CREATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['nvme_remote_controller']._options = None
  _globals['_CREATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['nvme_remote_controller']._serialized_options = b'\342A\001\002'
  _globals['_CREATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['nvme_remote_controller_id']._options = None
  _globals['_CREATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['nvme_remote_controller_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETENVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETENVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/NvmeRemoteController'
  _globals['_DELETENVMEREMOTECONTROLLERREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETENVMEREMOTECONTROLLERREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['nvme_remote_controller']._options = None
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['nvme_remote_controller']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMEREMOTECONTROLLERSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNVMEREMOTECONTROLLERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMEREMOTECONTROLLERSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNVMEREMOTECONTROLLERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETNVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/NvmeRemoteController'
  _globals['_RESETNVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_RESETNVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/NvmeRemoteController'
  _globals['_STATSNVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSNVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/NvmeRemoteController'
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A(\022&opi_api.storage.v1/NvmeRemoteNamespace'
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETNVMEREMOTENAMESPACEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNVMEREMOTENAMESPACEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A(\n&opi_api.storage.v1/NvmeRemoteNamespace'
  _globals['_CREATENVMEPATHREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATENVMEPATHREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/NvmeRemoteController'
  _globals['_CREATENVMEPATHREQUEST'].fields_by_name['nvme_path']._options = None
  _globals['_CREATENVMEPATHREQUEST'].fields_by_name['nvme_path']._serialized_options = b'\342A\001\002'
  _globals['_CREATENVMEPATHREQUEST'].fields_by_name['nvme_path_id']._options = None
  _globals['_CREATENVMEPATHREQUEST'].fields_by_name['nvme_path_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETENVMEPATHREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETENVMEPATHREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\035\n\033opi_api.storage.v1/NvmePath'
  _globals['_DELETENVMEPATHREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETENVMEPATHREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMEPATHREQUEST'].fields_by_name['nvme_path']._options = None
  _globals['_UPDATENVMEPATHREQUEST'].fields_by_name['nvme_path']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENVMEPATHREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATENVMEPATHREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMEPATHREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATENVMEPATHREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMEPATHSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTNVMEPATHSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\035\022\033opi_api.storage.v1/NvmePath'
  _globals['_LISTNVMEPATHSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNVMEPATHSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMEPATHSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNVMEPATHSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETNVMEPATHREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNVMEPATHREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\035\n\033opi_api.storage.v1/NvmePath'
  _globals['_STATSNVMEPATHREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSNVMEPATHREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\035\n\033opi_api.storage.v1/NvmePath'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['CreateNvmeRemoteController']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['CreateNvmeRemoteController']._serialized_options = b'\332A0nvme_remote_controller,nvme_remote_controller_id\202\323\344\223\0023\"\031/v1/nvmeRemoteControllers:\026nvme_remote_controller'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['DeleteNvmeRemoteController']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['DeleteNvmeRemoteController']._serialized_options = b'\332A\004name\202\323\344\223\002$*\"/v1/{name=nvmeRemoteControllers/*}'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['UpdateNvmeRemoteController']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['UpdateNvmeRemoteController']._serialized_options = b'\332A\"nvme_remote_controller,update_mask\202\323\344\223\002S29/v1/{nvme_remote_controller.name=nvmeRemoteControllers/*}:\026nvme_remote_controller'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ListNvmeRemoteControllers']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ListNvmeRemoteControllers']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/nvmeRemoteControllers'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['GetNvmeRemoteController']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['GetNvmeRemoteController']._serialized_options = b'\332A\004name\202\323\344\223\002$\022\"/v1/{name=nvmeRemoteControllers/*}'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ResetNvmeRemoteController']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ResetNvmeRemoteController']._serialized_options = b'\332A\004name\202\323\344\223\002-\"(/v1/{name=nvmeRemoteControllers/*}:reset:\001*'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['StatsNvmeRemoteController']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['StatsNvmeRemoteController']._serialized_options = b'\332A\004name\202\323\344\223\002*\022(/v1/{name=nvmeRemoteControllers/*}:stats'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ListNvmeRemoteNamespaces']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ListNvmeRemoteNamespaces']._serialized_options = b'\332A\006parent\202\323\344\223\002;\0229/v1/{parent=nvmeRemoteControllers/*}/nvmeRemoteNamespaces'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['GetNvmeRemoteNamespace']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['GetNvmeRemoteNamespace']._serialized_options = b'\332A\004name\202\323\344\223\002;\0229/v1/{name=nvmeRemoteControllers/*/nvmeRemoteNamespaces/*}'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['CreateNvmePath']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['CreateNvmePath']._serialized_options = b'\332A\035parent,nvme_path,nvme_path_id\202\323\344\223\002;\"./v1/{parent=nvmeRemoteControllers/*}/nvmePaths:\tnvme_path'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['DeleteNvmePath']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['DeleteNvmePath']._serialized_options = b'\332A\004name\202\323\344\223\0020*./v1/{name=nvmeRemoteControllers/*/nvmePaths/*}'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['UpdateNvmePath']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['UpdateNvmePath']._serialized_options = b'\332A\025nvme_path,update_mask\202\323\344\223\002E28/v1/{nvme_path.name=nvmeRemoteControllers/*/nvmePaths/*}:\tnvme_path'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ListNvmePaths']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ListNvmePaths']._serialized_options = b'\332A\006parent\202\323\344\223\0020\022./v1/{parent=nvmeRemoteControllers/*}/nvmePaths'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['GetNvmePath']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['GetNvmePath']._serialized_options = b'\332A\004name\202\323\344\223\0020\022./v1/{name=nvmeRemoteControllers/*/nvmePaths/*}'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['StatsNvmePath']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['StatsNvmePath']._serialized_options = b'\332A\004name\202\323\344\223\0026\0224/v1/{name=nvmeRemoteControllers/*/nvmePaths/*}:stats'
  _globals['_NVMEMULTIPATH']._serialized_start=4433
  _globals['_NVMEMULTIPATH']._serialized_end=4567
  _globals['_NVMEREMOTECONTROLLER']._serialized_start=238
  _globals['_NVMEREMOTECONTROLLER']._serialized_end=626
  _globals['_TCPCONTROLLER']._serialized_start=628
  _globals['_TCPCONTROLLER']._serialized_end=723
  _globals['_NVMEPATH']._serialized_start=726
  _globals['_NVMEPATH']._serialized_end=1034
  _globals['_FABRICSPATH']._serialized_start=1037
  _globals['_FABRICSPATH']._serialized_end=1301
  _globals['_NVMEREMOTENAMESPACE']._serialized_start=1304
  _globals['_NVMEREMOTENAMESPACE']._serialized_end=1618
  _globals['_CREATENVMEREMOTECONTROLLERREQUEST']._serialized_start=1621
  _globals['_CREATENVMEREMOTECONTROLLERREQUEST']._serialized_end=1823
  _globals['_DELETENVMEREMOTECONTROLLERREQUEST']._serialized_start=1826
  _globals['_DELETENVMEREMOTECONTROLLERREQUEST']._serialized_end=1974
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST']._serialized_start=1977
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST']._serialized_end=2224
  _globals['_LISTNVMEREMOTECONTROLLERSREQUEST']._serialized_start=2226
  _globals['_LISTNVMEREMOTECONTROLLERSREQUEST']._serialized_end=2332
  _globals['_LISTNVMEREMOTECONTROLLERSRESPONSE']._serialized_start=2335
  _globals['_LISTNVMEREMOTECONTROLLERSRESPONSE']._serialized_end=2508
  _globals['_GETNVMEREMOTECONTROLLERREQUEST']._serialized_start=2510
  _globals['_GETNVMEREMOTECONTROLLERREQUEST']._serialized_end=2612
  _globals['_RESETNVMEREMOTECONTROLLERREQUEST']._serialized_start=2614
  _globals['_RESETNVMEREMOTECONTROLLERREQUEST']._serialized_end=2718
  _globals['_STATSNVMEREMOTECONTROLLERREQUEST']._serialized_start=2720
  _globals['_STATSNVMEREMOTECONTROLLERREQUEST']._serialized_end=2824
  _globals['_STATSNVMEREMOTECONTROLLERRESPONSE']._serialized_start=2826
  _globals['_STATSNVMEREMOTECONTROLLERRESPONSE']._serialized_end=2916
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST']._serialized_start=2919
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST']._serialized_end=3097
  _globals['_LISTNVMEREMOTENAMESPACESRESPONSE']._serialized_start=3100
  _globals['_LISTNVMEREMOTENAMESPACESRESPONSE']._serialized_end=3269
  _globals['_GETNVMEREMOTENAMESPACEREQUEST']._serialized_start=3271
  _globals['_GETNVMEREMOTENAMESPACEREQUEST']._serialized_end=3371
  _globals['_CREATENVMEPATHREQUEST']._serialized_start=3374
  _globals['_CREATENVMEPATHREQUEST']._serialized_end=3576
  _globals['_DELETENVMEPATHREQUEST']._serialized_start=3578
  _globals['_DELETENVMEPATHREQUEST']._serialized_end=3702
  _globals['_UPDATENVMEPATHREQUEST']._serialized_start=3705
  _globals['_UPDATENVMEPATHREQUEST']._serialized_end=3903
  _globals['_LISTNVMEPATHSREQUEST']._serialized_start=3906
  _globals['_LISTNVMEPATHSREQUEST']._serialized_end=4062
  _globals['_LISTNVMEPATHSRESPONSE']._serialized_start=4064
  _globals['_LISTNVMEPATHSRESPONSE']._serialized_end=4188
  _globals['_GETNVMEPATHREQUEST']._serialized_start=4190
  _globals['_GETNVMEPATHREQUEST']._serialized_end=4268
  _globals['_STATSNVMEPATHREQUEST']._serialized_start=4270
  _globals['_STATSNVMEPATHREQUEST']._serialized_end=4350
  _globals['_STATSNVMEPATHRESPONSE']._serialized_start=4352
  _globals['_STATSNVMEPATHRESPONSE']._serialized_end=4430
  _globals['_NVMEREMOTECONTROLLERSERVICE']._serialized_start=4570
  _globals['_NVMEREMOTECONTROLLERSERVICE']._serialized_end=7392
# @@protoc_insertion_point(module_scope)
